#
# spec file for package littlewizard
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           littlewizard
Version:        1.2.2
Release:        18.4
Summary:        Development Environment for Children
License:        GPL-2.0-or-later
Group:          Development/Tools/IDE
Url:            https://littlewizard.sourceforge.net/
Source0:        %{name}-%{version}.tar.bz2
Source1:        littlewizard.1
Source2:        littlewizard.xpm
Patch0:         littlewizard-1.2.2-do-not-override-toolbar-style.patch
Patch1:         littlewizard-desktop-file.patch
Patch2:         littlewizard-reproducible_build.patch
BuildRequires:  gcc-c++
BuildRequires:  gettext-devel
BuildRequires:  gnome-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(libxml-2.0) >= 2.4
Recommends:     littlewizard-examples
%if 0%{?suse_version}
BuildRequires:  update-desktop-files
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Little Wizard is created especially for primary school children. It allows to
learn using main elements of present computer languages, including: variables,
expressions, loops, conditions, logical blocks. Every element of language is
represented by an intuitive icon. It allows program Little Wizard without
using keyboard, only mouse.

%package devel
Summary:        Development headers and files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
The littlewizard-devel package contains libraries and header files for
littlewizard developing.

%lang_package

%prep
%setup -q
%patch -P 0
%patch -P 1 -p1
%patch -P 2 -p1

%build
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install

%suse_update_desktop_file -u littlewizard

# removing useless files
rm -rf %{buildroot}%{_bindir}/littlewizardtest
rm -rf %{buildroot}%{_prefix}/doc/littlewizard
rm -rf %{buildroot}%{_libdir}/*.*a

# man page
mkdir -p %{buildroot}%{_mandir}/man1
install -m644 %{SOURCE1} %{buildroot}%{_mandir}/man1

# desktop icon
install -Dm644 %{SOURCE2} %{buildroot}%{_datadir}/pixmaps/littlewizard.xpm
%find_lang %{name}

%post
/sbin/ldconfig
%if 0%{?suse_version} > 1130
%desktop_database_post
%endif

%postun
/sbin/ldconfig
%if 0%{?suse_version} > 1130
%desktop_database_postun
%endif

%files -f %{name}.lang
%defattr(-,root,root)
%if 0%{?suse_version} >= 01500
%license COPYING
%else
%doc COPYING
%endif
%doc AUTHORS ChangeLog README TODO
%dir %{_datadir}/icons/gnome/48x48/mimetypes
%{_bindir}/littlewizard
%{_datadir}/littlewizard
%{_datadir}/applications/littlewizard.desktop
%{_datadir}/icons/gnome/48x48/mimetypes/gnome-mime-application-x-littlewizard.png
%{_datadir}/icons/gnome/scalable/mimetypes/gnome-mime-application-x-littlewizard.svg
%{_datadir}/mime/packages/littlewizard.xml
%{_datadir}/pixmaps/littlewizard
%{_datadir}/pixmaps/littlewizard.xpm
%{_libdir}/liblanguage.so.*
%{_libdir}/liblw.so.*
%{_mandir}/man1/littlewizard.1%{?ext_man}

%files devel
%defattr(-,root,root)
%{_includedir}/*
%{_libdir}/liblanguage.so
%{_libdir}/liblw.so

%changelog
* Fri Mar  1 2024 pgajdos@suse.com
- Use %%patch -P N instead of deprecated %%patchN.
* Tue Oct 29 2019 lars@linux-schulserver.de - 1.2.2
- added littlewizard-reproducible_build.patch from Reiner Herrmann
- added littlewizard.xpm for desktop file from Debian
- patch the existing desktop file: added littlewizard-desktop-file.patch
* Tue Sep 24 2019 lars@linux-schulserver.de - 1.2.2
- use X-KDE-Edu-Teaching as desktop category
- use SSL for Url
* Mon Mar 18 2019 lars@linux-schulserver.de - 1.2.2
- spec file cleanup:
  + use new SPDX tag for license string
  + package COPYING file
* Wed Sep 14 2011 kirill.kirillov@gmail.com
- added littlewizard-1.2.2-do-not-override-toolbar-style.patch
* Tue Sep  6 2011 kirill.kirillov@gmail.com
- removed littlewizardtest binary
- added man page from Debian
* Sat Mar 14 2009 kirill.kirillov@gmail.com
- added "Recommends: littlewizard-examples"
* Wed Oct  8 2008 lars@linux-schulserver.de
- fix filelist
* Thu Sep 25 2008 lars@linux-schulserver.de
- moved to Education base repository
* Sat Sep  6 2008 kirill.kirillov@gmail.com
- Update to release 1.2.2
  + Added Welsh and Greek translations
* Mon Aug 18 2008 kirill.kirillov@gmail.com
- Update to the bug fix release 1.2.1
  + interuption of "go" instruction fixed
  + proper detection of non command at the begining of the program
  + using the variables as argument for commands which need some time
    to finish fixed
  + destroy program data immediately after finish program, should fix seg
    faults when program is modified before program window is closed
* Tue Jul  1 2008 kirill.kirillov@gmail.com
- added littlewizard-1.2.0-fix-mime-type.patch
* Mon Jun 30 2008 kirill.kirillov@gmail.com
- Update to the next major release 1.2.0
  + New control flow commands "else", "break", "continue", "step"
  + Command "read" for user interactivity
  + Command "concatenate" for concatenating the strings
  + Command "length" for obtaining the length of the string or size of an array
  + Command "rand" behaves like in Pascal, it now generates values between 0 <= x < v
  + Boolean values (but dynamic "C" like casting still possible)
  + Smart comparation of the values, numerical or lexigraphical depending on the content.
  + Remarks
  + Mostly rewritten parser and interpreter part
  + Possibility to set initial position and direction of the wizard
  + Moving tiles on world board using a "SHIFT" key
  + Mime support (project files have own icon and can be loaded from the browser)
  + Memory leaks fixes and various optimizations, etc
- Dropped gcc 4.3 patch
* Sun Jun 29 2008 Andrea Florio andrea@opensuse.org
- added gcc 4.3 patch
- added -devel package
- added -debuginfo
- made rpmlint happy, now build on openSUSE 11.0
* Fri Jul 27 2007 kirill.kirillov@gmail.com
- Update to the bug fix release 1.1.5
* Thu Jan 11 2007 Piotr Pacholak <obi.gts@gmail.com>
- BR: gcc-c++
* Thu Jan 11 2007 Piotr Pacholak <obi.gts@gmail.com>
- BR: libxml2-devel
* Thu Nov 16 2006 Piotr Pacholak <obi.gts@gmail.com>
- up to 1.1.4
* Tue May 23 2006 Piotr Pacholak <obi.gts@gmail.com>
- Rebuild
* Wed May 17 2006 Piotr Pacholak <obi.gts@gmail.com>
- Rebuild
* Tue May 16 2006 Piotr Pacholak <obi.gts@gmail.com>
- initial release
